from prodigy.gameData import gameData
from prodigy.gameStatus import gameStatus
from prodigy.get_asset import get_asset
from prodigy.get_friend_requests import get_friend_requests
from prodigy.get_userID import get_userID
from prodigy.player import player, update_player
from prodigy.prodigy import Prodigy
from prodigy.tokenify import tokenify

__all__ = [
    "gameData",
    "gameStatus",
    "get_asset",
    "get_friend_requests",
    "get_userID",
    "player",
    "update_player",
    "Prodigy",
    "tokenify"
]
__version__ = "1.0.0"
